package com.miaxis.customer.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.miaxis.common.annotation.Excel;
import com.miaxis.common.core.domain.BaseBusinessEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * 客户信息对象 customer_info
 *
 * @author miaxis
 * @date 2021-03-10
 */
@Data
@TableName("customer_info")
@ApiModel(value = "CustomerInfo", description = "客户信息对象")
public class CustomerInfo extends BaseBusinessEntity{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    @TableId(value = "id")
    @ApiModelProperty(value = "主键")
    private Long id;

    /** 公司名称 */
    @Excel(name = "公司名称")
    @TableField("corporate_name")
    @ApiModelProperty(value = "公司名称")
    private String corporateName;

    /** 业务类型  0：内部小程序、1：外部小程序 */
    @Excel(name = "业务类型  0：内部小程序、1：外部小程序")
    @TableField("business_type")
    @ApiModelProperty(value = "业务类型  0：内部小程序、1：外部小程序")
    private Integer businessType;

    /** 公司LOGO图片--（对应file_info的id） */
    @Excel(name = "公司LOGO图片--（对应file_info的id）", readConverterExp = "对=应file_info的id")
    @TableField("corporate_logo")
    @ApiModelProperty(value = "公司LOGO图片--（对应file_info的id）")
    private Long corporateLogo;

    /** 客户来源  0：电话营销、1：主动来电、2：客户介绍、3：朋友介绍、4：销售推广、5：网络搜索、6：广告杂志、7：展会促销、8：其他 */
    @Excel(name = "客户来源  0：电话营销、1：主动来电、2：客户介绍、3：朋友介绍、4：销售推广、5：网络搜索、6：广告杂志、7：展会促销、8：其他")
    @TableField("customer_source")
    @ApiModelProperty(value = "客户来源  0：电话营销、1：主动来电、2：客户介绍、3：朋友介绍、4：销售推广、5：网络搜索、6：广告杂志、7：展会促销、8：其他")
    private Integer customerSource;

    /** 所在城市编码（对应城市表） */
    @Excel(name = "所在城市编码（对应城市表）", readConverterExp = "对=应城市表")
    @TableField("city_code")
    @ApiModelProperty(value = "所在城市编码（对应城市表）")
    private String cityCode;

    /** 归属人员--关联用户表 */
    @Excel(name = "归属人员--关联用户表")
    @TableField("attributed_personnel")
    @ApiModelProperty(value = "归属人员--关联用户表")
    private Long attributedPersonnel;

    /** 详细地址 */
    @Excel(name = "详细地址")
    @TableField("detailed_address")
    @ApiModelProperty(value = "详细地址")
    private String detailedAddress;

    /** 行业类型---关联product_type_info 品类表 */
    @Excel(name = "行业类型---关联product_type_info 品类表")
    @TableField("industry_type")
    @ApiModelProperty(value = "行业类型---关联product_type_info 品类表")
    private Long industryType;

    /** 公司电话 */
    @Excel(name = "公司电话")
    @TableField("corporate_phone")
    @ApiModelProperty(value = "公司电话")
    private String corporatePhone;

    /** 公司联系人 */
    @Excel(name = "公司联系人")
    @TableField("corporate_contacts")
    @ApiModelProperty(value = "公司联系人")
    private String corporateContacts;

    /** 手机号码 */
    @Excel(name = "手机号码")
    @TableField("phone")
    @ApiModelProperty(value = "手机号码")
    private String phone;

    /** 客户星级  1：一星、2：二星、3：三星、4：四星、5：五星 */
    @Excel(name = "客户星级  1：一星、2：二星、3：三星、4：四星、5：五星")
    @TableField("customer_star")
    @ApiModelProperty(value = "客户星级  1：一星、2：二星、3：三星、4：四星、5：五星")
    private Integer customerStar;

    /** 企业税号 */
    @Excel(name = "企业税号")
    @TableField("enterprise_tax_number")
    @ApiModelProperty(value = "企业税号")
    private String enterpriseTaxNumber;

    /** 发票抬头 */
    @Excel(name = "发票抬头")
    @TableField("invoice_title")
    @ApiModelProperty(value = "发票抬头")
    private String invoiceTitle;

    /** 开户银行 */
    @Excel(name = "开户银行")
    @TableField("bank_of_deposit")
    @ApiModelProperty(value = "开户银行")
    private String bankOfDeposit;

    /** 银行帐户 */
    @Excel(name = "银行帐户")
    @TableField("bank_account")
    @ApiModelProperty(value = "银行帐户")
    private String bankAccount;

    /** 财务电话号码 */
    @Excel(name = "财务电话号码")
    @TableField("finance_phone")
    @ApiModelProperty(value = "财务电话号码")
    private String financePhone;

    /** 传真号码 */
    @Excel(name = "传真号码")
    @TableField("fax_number")
    @ApiModelProperty(value = "传真号码")
    private String faxNumber;

    /** 小程序地址 */
    @Excel(name = "小程序地址")
    @TableField("applet_address")
    @ApiModelProperty(value = "小程序地址")
    private String appletAddress;

    /** 小程序图标---（对应file_info的id） */
    @Excel(name = "小程序图标---（对应file_info的id）", readConverterExp = "对=应file_info的id")
    @TableField("applet_logo")
    @ApiModelProperty(value = "小程序图标---（对应file_info的id）")
    private Long appletLogo;

    /** 小程序二维码---（对应file_info的id） */
    @Excel(name = "小程序二维码---（对应file_info的id）", readConverterExp = "对=应file_info的id")
    @TableField("applet_qr_code")
    @ApiModelProperty(value = "小程序二维码---（对应file_info的id）")
    private Long appletQrCode;

    /** 小程序介绍 */
    @Excel(name = "小程序介绍")
    @TableField("applet_introduce")
    @ApiModelProperty(value = "小程序介绍")
    private String appletIntroduce;

    /** 上架状态  0：已上架、1：未上架 */
    @Excel(name = "上架状态  0：已上架、1：未上架")
    @TableField("shelf_status")
    @ApiModelProperty(value = "上架状态  0：已上架、1：未上架")
    private Integer shelfStatus;

    /** 状态  0：有效(默认)、1：失效 （伪删除） */
    @Excel(name = "状态  0：有效(默认)、1：失效 （伪删除）", readConverterExp = "伪=删除")
    @TableField("status")
    @ApiModelProperty(value = "状态  0：有效(默认)、1：失效 （伪删除）")
    private Integer status;


}
