package com.miaxis.customer.service;

import java.util.List;

import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.domain.entity.UserInfo;
import com.miaxis.customer.domain.CustomerInfo;
import com.baomidou.mybatisplus.extension.service.IService;
import com.miaxis.customer.vo.CustomerInfoVo;

/**
 * 客户信息Service接口
 *
 * @author miaxis
 * @date 2021-03-10
 */
public interface ICustomerInfoService extends IService<CustomerInfo>{
    /**
     * 查询客户信息列表
     *
     * @param customerInfo 客户信息
     * @return 客户信息集合
     */
    List<CustomerInfo> selectCustomerInfoList(CustomerInfo customerInfo);

    /**
     * 更新 0：上架 / 1：下架
     * @param ids
     * @param shelfStatus
     * @return
     */
    Response updateShelfStatus(Long[] ids, Integer shelfStatus);


    /**
     * 删除客户信息(伪删除)
     * @param ids
     * @return
     */
    Response removeCustomerByIds(Long[] ids);

    /**
     * 获取客户信息详细信息
     * @param id
     * @return
     */
    Response<CustomerInfoVo> getCustomerById(Long id);

    /**
     * applet
     * 查询所属品类商家
     * @param productId
     * @return
     */
    List<CustomerInfoVo> getCustomerListByProductId(Long productId);

    /**
     * applet
     * 收藏商家
     * @param userInfo 当前用户
     * @param id 商家id
     * @return
     */
    Response collectionBusiness(UserInfo userInfo, Long id);

    /**
     * 查询精选商家列表 根据收藏数排行
     * @return
     */
    List<CustomerInfoVo> getCustomerListByCollectionCount();

}
